summaryrefslogtreecommitdiff
path: root/tool
diff options
context:
space:
mode:
authorStef Walter <stefw@collabora.co.uk>2010-12-10 22:09:42 +0000
committerStef Walter <stefw@collabora.co.uk>2010-12-10 22:09:42 +0000
commit2ac2d39cfd9b4fa265f560f1b0f57b006f019ad0 (patch)
tree254feaf4e45601963d3e6dda81e48f8325b0428f /tool
parent2d97fa8b25bd328c5f678412e2804c0d6bbeb071 (diff)
downloadgnome-keyring-2ac2d39cfd9b4fa265f560f1b0f57b006f019ad0.tar.gz
Change terminology to 'pinned certificate' from 'exception'.
The matching terminology of 'anchored certificate' and 'pinned certificate' makes things consistent and understandable.
Diffstat (limited to 'tool')
-rw-r--r--tool/gkr-tool-trust.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/tool/gkr-tool-trust.c b/tool/gkr-tool-trust.c
index edd0b2cd..967a3c16 100644
--- a/tool/gkr-tool-trust.c
+++ b/tool/gkr-tool-trust.c
@@ -1,5 +1,5 @@
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
/* gkr-tool-trust.c: Command line certificate trust exceptions
Copyright (C) 2010 Stefan Walter
@@ -102,7 +102,7 @@ purpose_to_string (GcrPurpose purpose)
}
static int
-get_certificate_exception (GcrCertificate *certificate, GcrPurpose purpose)
+get_pinned_certificate (GcrCertificate *certificate, GcrPurpose purpose)
{
GError *error = NULL;
const gchar *string;
@@ -1,5 +1,5 @@
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* gkr-tool-trust.c: Command line certificate trust exceptions
+/* gkr-tool-trust.c: Command line pinned certificates
Copyright (C) 2010 Stefan Walter